%% sims.cls
%% Copyright 2023 DLR and the  Association
%
% This work may be distributed and/or modified under the
% conditions of the LaTeX Project Public License, either version 1.3
% of this license or (at your option) any later version.
% The latest version of this license is in
%   http://www.latex-project.org/lppl.txt
% and version 1.3 or later is part of all distributions of LaTeX
% version 2005/12/01 or later.
%
% This work is 'maintained' on GitHub:
%   https://github.com/modelica-association/conference-templates
%
% This work consists of all files in the GitHub repository except
% a) The files indicated by .gitignore files
% b) The GitHub management files .gitignore, *.md
%
% This class is created from the template for the SIMS2023 conference
%
% Layout and Author: Valentin Scheiff,  Mälardalen university, Sweden,  2023
%

\ProvidesClass{sims}[2023/03/06 SIMS2023 conference template]

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}} 
\ProcessOptions\relax
\LoadClass[10pt,twocolumn]{scrartcl}


% Load required packages
\RequirePackage{titlesec}
\RequirePackage[T1]{fontenc}   %% get hyphenation and accented letters right


\RequirePackage{fancyhdr}
\RequirePackage{xcolor}
\RequirePackage{multicol}

\RequirePackage{geometry} 
\geometry{left=20mm, right=20mm, top=15mm, bottom=35mm, noheadfoot}

\RequirePackage{graphicx}      %% use graphics
\RequirePackage{mathptmx}      %% use fitting times fonts also in formulas
\RequirePackage{amsmath}       %% get support for pretty math formulas

%Space between 2 columns
\setlength{\parindent}{0pt}
\setlength{\columnsep}{1.2cm}

% Define section format
\titleformat{\section}
{\bfseries\fontsize{10}{12}\selectfont} % Format
{\thesection} % Label
{1em} % Separation between label and title
{} % Before code

% Define subsection format
\titleformat{\subsection}
{\fontsize{10}{12}\selectfont\itshape} % Format
{\thesubsection} % Label
{1em} % Separation between label and title
{} % Before code

% Define subsubsection format
\titleformat{\subsubsection}
{\fontsize{10}{12}\selectfont\itshape} % Format
{\thesubsubsection} % Label
{1em} % Separation between label and title
{} % Before code

%Times New Roman font
\RequirePackage{fontspec}
\setmainfont{Times New Roman}

% Define header style
\fancyhf{} % Clear header and footer
\setlength{\headheight}{30pt}
\renewcommand{\headrulewidth}{0pt}
\fancyhead[L]{\begin{minipage}{\textwidth}\sffamily\color{gray}\fontsize{10}{12}\selectfont SIMS 64 \hfill Västerås, Sweden, September 26-27, 2023  \vspace{\baselineskip} \end{minipage}}




% abstract environment
\renewenvironment{abstract}{
        \vskip-5em 
  	\begin{minipage}[t]{\textwidth}
  		\noindent%
  		{\flushleft\bfseries\fontsize{10}{12}\selectfont\abstractname\par\vskip2em}%
  	\end{minipage}\par%
   \vskip1em
}

% do not change these lines:
%\pagestyle{empty}                %% no page numbers!

% Some sizes
\renewcommand{\normalsize}  {\fontsize{10.5pt}{12.3pt}\selectfont}
\renewcommand{\small}       {\fontsize{09.5pt}{11.1pt}\selectfont}
\renewcommand{\footnotesize}{\fontsize{08.5pt}{09.9pt}\selectfont}

% Labels and captions
\RequirePackage[labelfont=bf, labelsep=period, font=small]{caption}  %% Get bold Figure/Table caption
                                                                 %% Set separator in figures to '.', set fontsize to small

% Prepare author info
\RequirePackage{authblk}                   %% Prepare author and affiliation blocks
\renewcommand\Authfont {\large}        %% Set author font
\renewcommand\Affilfont{\normalsize}   %% Set affiliation font
\renewcommand\Authsep  {\quad}         %% Set text between authors names
\renewcommand\Authand  {\quad}         %% Set text between authors names
\renewcommand\Authands {\quad}         %% Set text between authors names

% Redefine \author's \and
\def\and{\quad}

% Redefine \title to be \textbf and move it up to a height similar to the Word template
\let\sims@title\title
\renewcommand{\title}[1]{\sims@title{\vspace{-1.0cm}\textbf{#1}}}

% Redefine \date for it not to be used
\date{} % <--- leave date empty
\renewcommand{\date}[1]{ \ClassWarningNoLine{sims}{Do not use the date command}}

% Redefine \maketitle to include \thispagestyle{empty}
\let\sims@maketitle\maketitle
\renewcommand{\maketitle}{\sims@maketitle\thispagestyle{fancy}\@afterindentfalse\@afterheading}

% Make headings nice and compact and make sure to use a new version
\RequirePackage{doi}             %% Create cor­rect hy­per­links for DOI num­bers
\renewcommand{\doitext}{}
\RequirePackage{apacite}

% Process backend
\newif\if@biber
\@biberfalse%   %% we default to backend=bibtex

\DeclareOption{backend=bibtex}{\@biberfalse}
\DeclareOption{backend=biber}{\@bibertrue}
\ProcessOptions% Process package options

\if@biber %% Process backend option "biber"
  \RequirePackage[backend=biber,
                  citestyle=authoryear,maxnames=2,maxbibnames=2]
                  {biblatex}
  \let\cite\parencite   %% normal \cite produces \parencite
  \let\sims@printbibliography\printbibliography
  \renewcommand{\printbibliography}{\small\sims@printbibliography\normalsize}%
  %
  \renewcommand*{\finalnamedelim}{\addspace\&\space}
\else %% Process (default) backend option "bibtex"
  \RequirePackage[round]{natbib}   %% author-year style referencing
%    \PassOptionsToClass{round}{natbib}
  \let\cite\citep              %% normal \cite produces \citep
  \let\sims@bibliography\bibliography
  \renewcommand{\bibliography}[1]{\bibliographystyle{apacite}\small\sims@bibliography{#1}\normalsize}
\fi


% captions settings
\RequirePackage{caption}
\captionsetup{labelfont={small,sf,bf}}
\setlength\belowcaptionskip{5pt}

% tweaking the footnotes
\RequirePackage[hang,flushmargin]{footmisc} 



% Professional tables
\RequirePackage{booktabs}

% SIMS2023 code configuration
\RequirePackage{color}
\RequirePackage{listings}
\input{resources/listings-sims.cfg}
\lstset{language = sims,
       basicstyle=\fontsize{9pt}{10.5pt}\ttfamily,
       backgroundcolor = \color{white}}



